==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkXOpenGLRenderWindow.java <==
// java wrapper for vtkXOpenGLRenderWindow object
//

package vtk;
import vtk.*;

public class vtkXOpenGLRenderWindow extends vtkOpenGLRenderWindow
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Start_2();
  public void Start()
    { Start_2(); }

  private native void Frame_3();
  public void Frame()
    { Frame_3(); }

  private native void WindowInitialize_4();
  public void WindowInitialize()
    { WindowInitialize_4(); }

  private native void Initialize_5();
  public void Initialize()
    { Initialize_5(); }

  private native void Finalize_6();
  public void Finalize()
    { Finalize_6(); }

  private native void SetFullScreen_7(int id0);
  public void SetFullScreen(int id0)
    { SetFullScreen_7(id0); }

  private native void WindowRemap_8();
  public void WindowRemap()
    { WindowRemap_8(); }

  private native void PrefFullScreen_9();
  public void PrefFullScreen()
    { PrefFullScreen_9(); }

  private native void SetSize_10(int id0,int id1);
  public void SetSize(int id0,int id1)
    { SetSize_10(id0,id1); }

  private native void SetSize_11(int id0[]);
  public void SetSize(int id0[])
    { SetSize_11(id0); }

  private native int GetDesiredDepth_12();
  public int GetDesiredDepth()
    { return GetDesiredDepth_12(); }

  private native void SetStereoCapableWindow_13(int id0);
  public void SetStereoCapableWindow(int id0)
    { SetStereoCapableWindow_13(id0); }

  private native void MakeCurrent_14();
  public void MakeCurrent()
    { MakeCurrent_14(); }

  private native boolean IsCurrent_15();
  public boolean IsCurrent()
    { return IsCurrent_15(); }

  private native void SetForceMakeCurrent_16();
  public void SetForceMakeCurrent()
    { SetForceMakeCurrent_16(); }

  private native String ReportCapabilities_17();
  public String ReportCapabilities()
    { return ReportCapabilities_17(); }

  private native int IsDirect_18();
  public int IsDirect()
    { return IsDirect_18(); }

  private native int[]  GetScreenSize_19();
  public int[]  GetScreenSize()
    { return GetScreenSize_19(); }

  private native int[]  GetPosition_20();
  public int[]  GetPosition()
    { return GetPosition_20(); }

  private native void SetWindowName_21(String id0);
  public void SetWindowName(String id0)
    { SetWindowName_21(id0); }

  private native boolean InitializeFromCurrentContext_22();
  public boolean InitializeFromCurrentContext()
    { return InitializeFromCurrentContext_22(); }

  private native void SetPosition_23(int id0,int id1);
  public void SetPosition(int id0,int id1)
    { SetPosition_23(id0,id1); }

  private native void SetPosition_24(int id0[]);
  public void SetPosition(int id0[])
    { SetPosition_24(id0); }

  private native void HideCursor_25();
  public void HideCursor()
    { HideCursor_25(); }

  private native void ShowCursor_26();
  public void ShowCursor()
    { ShowCursor_26(); }

  private native void SetCurrentCursor_27(int id0);
  public void SetCurrentCursor(int id0)
    { SetCurrentCursor_27(id0); }

  private native int GetEventPending_28();
  public int GetEventPending()
    { return GetEventPending_28(); }

  private native void SetWindowInfo_29(String id0);
  public void SetWindowInfo(String id0)
    { SetWindowInfo_29(id0); }

  private native void SetNextWindowInfo_30(String id0);
  public void SetNextWindowInfo(String id0)
    { SetNextWindowInfo_30(id0); }

  private native void SetParentInfo_31(String id0);
  public void SetParentInfo(String id0)
    { SetParentInfo_31(id0); }

  private native void Render_32();
  public void Render()
    { Render_32(); }

  private native void SetOffScreenRendering_33(int id0);
  public void SetOffScreenRendering(int id0)
    { SetOffScreenRendering_33(id0); }

  private native void PushContext_34();
  public void PushContext()
    { PushContext_34(); }

  private native void PopContext_35();
  public void PopContext()
    { PopContext_35(); }

  public vtkXOpenGLRenderWindow() { super(); }

  public vtkXOpenGLRenderWindow(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkXOpenGLRenderWindow.java <==
// java wrapper for vtkXOpenGLRenderWindow object
//

package vtk;
import vtk.*;

public class vtkXOpenGLRenderWindow extends vtkOpenGLRenderWindow
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Start_2();
  public void Start()
    { Start_2(); }

  private native void Frame_3();
  public void Frame()
    { Frame_3(); }

  private native void WindowInitialize_4();
  public void WindowInitialize()
    { WindowInitialize_4(); }

  private native void Initialize_5();
  public void Initialize()
    { Initialize_5(); }

  private native void Finalize_6();
  public void Finalize()
    { Finalize_6(); }

  private native void SetFullScreen_7(int id0);
  public void SetFullScreen(int id0)
    { SetFullScreen_7(id0); }

  private native void WindowRemap_8();
  public void WindowRemap()
    { WindowRemap_8(); }

  private native void PrefFullScreen_9();
  public void PrefFullScreen()
    { PrefFullScreen_9(); }

  private native void SetSize_10(int id0,int id1);
  public void SetSize(int id0,int id1)
    { SetSize_10(id0,id1); }

  private native void SetSize_11(int id0[]);
  public void SetSize(int id0[])
    { SetSize_11(id0); }

  private native int GetDesiredDepth_12();
  public int GetDesiredDepth()
    { return GetDesiredDepth_12(); }

  private native void SetStereoCapableWindow_13(int id0);
  public void SetStereoCapableWindow(int id0)
    { SetStereoCapableWindow_13(id0); }

  private native void MakeCurrent_14();
  public void MakeCurrent()
    { MakeCurrent_14(); }

  private native boolean IsCurrent_15();
  public boolean IsCurrent()
    { return IsCurrent_15(); }

  private native void SetForceMakeCurrent_16();
  public void SetForceMakeCurrent()
    { SetForceMakeCurrent_16(); }

  private native String ReportCapabilities_17();
  public String ReportCapabilities()
    { return ReportCapabilities_17(); }

  private native int IsDirect_18();
  public int IsDirect()
    { return IsDirect_18(); }

  private native int[]  GetScreenSize_19();
  public int[]  GetScreenSize()
    { return GetScreenSize_19(); }

  private native int[]  GetPosition_20();
  public int[]  GetPosition()
    { return GetPosition_20(); }

  private native void SetWindowName_21(String id0);
  public void SetWindowName(String id0)
    { SetWindowName_21(id0); }

  private native boolean InitializeFromCurrentContext_22();
  public boolean InitializeFromCurrentContext()
    { return InitializeFromCurrentContext_22(); }

  private native void SetPosition_23(int id0,int id1);
  public void SetPosition(int id0,int id1)
    { SetPosition_23(id0,id1); }

  private native void SetPosition_24(int id0[]);
  public void SetPosition(int id0[])
    { SetPosition_24(id0); }

  private native void HideCursor_25();
  public void HideCursor()
    { HideCursor_25(); }

  private native void ShowCursor_26();
  public void ShowCursor()
    { ShowCursor_26(); }

  private native void SetCurrentCursor_27(int id0);
  public void SetCurrentCursor(int id0)
    { SetCurrentCursor_27(id0); }

  private native int GetEventPending_28();
  public int GetEventPending()
    { return GetEventPending_28(); }

  private native void SetWindowInfo_29(String id0);
  public void SetWindowInfo(String id0)
    { SetWindowInfo_29(id0); }

  private native void SetNextWindowInfo_30(String id0);
  public void SetNextWindowInfo(String id0)
    { SetNextWindowInfo_30(id0); }

  private native void SetParentInfo_31(String id0);
  public void SetParentInfo(String id0)
    { SetParentInfo_31(id0); }

  private native void Render_32();
  public void Render()
    { Render_32(); }

  private native void SetOffScreenRendering_33(int id0);
  public void SetOffScreenRendering(int id0)
    { SetOffScreenRendering_33(id0); }

  private native void PushContext_34();
  public void PushContext()
    { PushContext_34(); }

  private native void PopContext_35();
  public void PopContext()
    { PopContext_35(); }

  public vtkXOpenGLRenderWindow() { super(); }

  public vtkXOpenGLRenderWindow(long id) { super(id); }
  public native long   VTKInit();

}
